/*
  Authors : initappz (Rahul Jograna)
  Website : https://initappz.com/
  App Name : Ultimate Salon Full App Flutter V3
  This App Template Source code is licensed as per the
  terms found in the Website https://initappz.com/license
  Copyright and Good Faith Purchasers © 2024-present initappz.
*/
import 'package:owner/app/backend/api/api.dart';
import 'package:owner/app/helper/shared_pref.dart';
import 'package:owner/app/util/constance.dart';
import 'package:get/get.dart';

class LoginParser {
  final SharedPreferencesManager sharedPreferencesManager;
  final ApiService apiService;

  LoginParser({required this.sharedPreferencesManager, required this.apiService});

  Future<Response> onLogin(dynamic body) async {
    var response = await apiService.postPublic(AppConstants.onLogin, body);
    return response;
  }

  int userLogin() {
    return sharedPreferencesManager.getInt('userLogin') ?? AppConstants.userLogin;
  }

  void saveToken(String token) {
    sharedPreferencesManager.putString('token', token);
  }

  void saveInfo(String id, String firstName, String lastName, String cover, String email, String mobile, String type) {
    sharedPreferencesManager.putString('uid', id);
    sharedPreferencesManager.putString('first_name', firstName);
    sharedPreferencesManager.putString('last_name', lastName);
    sharedPreferencesManager.putString('email', email);
    sharedPreferencesManager.putString('cover', cover);
    sharedPreferencesManager.putString('phone', mobile);
    sharedPreferencesManager.putString('type', type);
  }

  void saveOtherInfo(String name, String cover, String background, double rating, String totalRating) {
    sharedPreferencesManager.putString('name', name);
    sharedPreferencesManager.putString('cover', cover);
    sharedPreferencesManager.putString('background', background);
    sharedPreferencesManager.putDouble('rating', rating);
    sharedPreferencesManager.putString('totalRating', totalRating);
  }

  String smsName() {
    return sharedPreferencesManager.getString('smsName') ?? AppConstants.defaultSMSGateway;
  }

  Future<Response> verifyPhoneWithFirebase(dynamic param) async {
    return await apiService.postPublic(AppConstants.verifyPhoneFirebase, param);
  }

  Future<Response> verifyPhone(dynamic param) async {
    return await apiService.postPublic(AppConstants.verifyPhone, param);
  }

  Future<Response> verifyOTP(dynamic param) async {
    return await apiService.postPublic(AppConstants.verifyOTP, param);
  }

  Future<Response> loginWithPhoneToken(dynamic param) async {
    return await apiService.postPublic(AppConstants.loginWithMobileToken, param);
  }

  Future<Response> updateProfile(var body, var token) async {
    var response = await apiService.postPrivate(AppConstants.updateFCM, body, token);
    return response;
  }

  String getFcmToken() {
    return sharedPreferencesManager.getString('fcm_token') ?? 'NA';
  }

  Future<Response> loginWithPhonePasswordPost(dynamic param) async {
    return await apiService.postPublic(AppConstants.loginWithPhonePassword, param);
  }

  void saveLanguage(String code) {
    sharedPreferencesManager.putString('language', code);
  }
}
