/*
  Authors : initappz (Rahul Jograna)
  Website : https://initappz.com/
  App Name : Ultimate Salon Full App Flutter V3
  This App Template Source code is licensed as per the
  terms found in the Website https://initappz.com/license
  Copyright and Good Faith Purchasers © 2024-present initappz.
*/
import 'package:flutter/material.dart';
import 'package:get/get.dart';
import 'package:google_maps_flutter/google_maps_flutter.dart';
import 'package:user/app/controller/near_controller.dart';
import 'package:user/app/env.dart';
import 'package:user/app/helper/map_style.dart';
import 'package:user/app/util/theme.dart';

class NearScreen extends StatefulWidget {
  const NearScreen({super.key});

  @override
  State<NearScreen> createState() => _NearScreenState();
}

class _NearScreenState extends State<NearScreen> {
  @override
  Widget build(BuildContext context) {
    void onMapCreated(GoogleMapController controller) {
      // controller.setMapStyle(Utils.mapStyles);
      Get.find<NearController>().googleMapsController.complete(controller);
    }

    return GetBuilder<NearController>(
      builder: (value) {
        return Scaffold(
          backgroundColor: ThemeProvider.whiteColor,
          body: value.apiCalled == false
              ? const Center(child: CircularProgressIndicator(color: ThemeProvider.appColor))
              : value.haveData == true
                  ? SingleChildScrollView(
                      child: Column(
                        children: [
                          SizedBox(
                            width: double.infinity,
                            height: 400,
                            child: GoogleMap(
                              myLocationEnabled: true,
                              compassEnabled: true,
                              tiltGesturesEnabled: false,
                              onMapCreated: onMapCreated,
                              markers: value.markers,
                              mapType: MapType.normal,
                              scrollGesturesEnabled: true,
                              zoomControlsEnabled: true,
                              zoomGesturesEnabled: true,
                              initialCameraPosition: value.initialCameraPosition,
                              style: Utils.mapStyles,
                            ),
                          ),
                          Container(
                            width: double.infinity,
                            height: 385,
                            color: ThemeProvider.whiteColor,
                            padding: const EdgeInsets.all(10),
                            child: Column(
                              children: [
                                Padding(
                                  padding: const EdgeInsets.only(top: 20, bottom: 10),
                                  child: Row(mainAxisAlignment: MainAxisAlignment.spaceBetween, children: [Text('Top Specialist'.tr, style: const TextStyle(fontSize: 14, fontFamily: 'bold'))]),
                                ),
                                SingleChildScrollView(
                                  scrollDirection: Axis.horizontal,
                                  child: Row(
                                    children: [
                                      for (var item in Get.find<NearController>().individualList)
                                        Padding(
                                          padding: const EdgeInsets.symmetric(horizontal: 10),
                                          child: Column(
                                            children: [
                                              InkWell(
                                                onTap: () => value.onSpecialist(item.uid as int),
                                                child: Container(
                                                  decoration: BoxDecoration(borderRadius: BorderRadius.circular(100.0), border: Border.all(width: 2, color: ThemeProvider.appColor)),
                                                  child: Padding(
                                                    padding: const EdgeInsets.all(3.0),
                                                    child: ClipRRect(
                                                      borderRadius: BorderRadius.circular(100),
                                                      child: SizedBox.fromSize(
                                                        size: const Size.fromRadius(25),
                                                        child: FadeInImage(
                                                          image: NetworkImage('${Environments.apiBaseURL}storage/images/${item.userInfo?.cover.toString()}'),
                                                          placeholder: const AssetImage("assets/images/placeholder.jpeg"),
                                                          imageErrorBuilder: (context, error, stackTrace) {
                                                            return Image.asset('assets/images/notfound.png', fit: BoxFit.cover);
                                                          },
                                                          fit: BoxFit.cover,
                                                        ),
                                                      ),
                                                    ),
                                                  ),
                                                ),
                                              ),
                                              const SizedBox(height: 5),
                                              Text(item.userInfo!.firstName.toString(), style: const TextStyle(fontFamily: 'semibold')),
                                              Text(item.userInfo!.lastName.toString(), style: const TextStyle(fontSize: 10)),
                                            ],
                                          ),
                                        )
                                    ],
                                  ),
                                ),
                                Padding(
                                  padding: const EdgeInsets.symmetric(vertical: 10),
                                  child: Row(mainAxisAlignment: MainAxisAlignment.spaceBetween, children: [Text('Top Salon'.tr, style: const TextStyle(fontSize: 14, fontFamily: 'bold'))]),
                                ),
                                Padding(
                                  padding: const EdgeInsets.only(bottom: 5),
                                  child: SingleChildScrollView(
                                    scrollDirection: Axis.horizontal,
                                    child: Padding(
                                      padding: const EdgeInsets.symmetric(horizontal: 10),
                                      child: Row(
                                        children: [
                                          for (var item in Get.find<NearController>().salonList)
                                            Container(
                                              margin: const EdgeInsets.only(right: 10),
                                              decoration: BoxDecoration(
                                                border: Border.all(color: Colors.grey),
                                                borderRadius: const BorderRadius.all(Radius.circular(10)),
                                              ),
                                              child: InkWell(
                                                onTap: () => value.onServices(item.uid as int),
                                                child: Column(
                                                  children: [
                                                    SizedBox(
                                                      height: 90,
                                                      width: 250,
                                                      child: ClipRRect(
                                                        borderRadius: const BorderRadius.only(topLeft: Radius.circular(10), topRight: Radius.circular(10)),
                                                        child: FadeInImage(
                                                          image: NetworkImage('${Environments.apiBaseURL}storage/images/${item.cover.toString()}'),
                                                          placeholder: const AssetImage("assets/images/placeholder.jpeg"),
                                                          imageErrorBuilder: (context, error, stackTrace) {
                                                            return Image.asset('assets/images/notfound.png', fit: BoxFit.cover);
                                                          },
                                                          fit: BoxFit.cover,
                                                        ),
                                                      ),
                                                    ),
                                                    SizedBox(
                                                      width: 250,
                                                      child: Stack(
                                                        children: [
                                                          Padding(
                                                            padding: const EdgeInsets.symmetric(horizontal: 10),
                                                            child: Column(
                                                              crossAxisAlignment: CrossAxisAlignment.start,
                                                              children: [
                                                                Padding(
                                                                  padding: const EdgeInsets.symmetric(vertical: 10),
                                                                  child: Row(
                                                                    mainAxisAlignment: MainAxisAlignment.spaceBetween,
                                                                    children: [
                                                                      Expanded(child: Text(item.name.toString(), overflow: TextOverflow.ellipsis, style: const TextStyle(fontSize: 15))),
                                                                      Row(
                                                                        children: [
                                                                          const Icon(Icons.star, color: Colors.orange, size: 17),
                                                                          const SizedBox(width: 5),
                                                                          Text(item.rating.toString(), style: const TextStyle(fontSize: 15))
                                                                        ],
                                                                      ),
                                                                    ],
                                                                  ),
                                                                ),
                                                                Padding(
                                                                  padding: const EdgeInsets.only(bottom: 15),
                                                                  child: Text(
                                                                    item.address!.length > 15 ? '${item.address!.substring(0, 27)}...' : item.address.toString(),
                                                                    overflow: TextOverflow.ellipsis,
                                                                    style: const TextStyle(fontSize: 12, color: ThemeProvider.greyColor),
                                                                  ),
                                                                ),
                                                              ],
                                                            ),
                                                          ),
                                                          Positioned(
                                                            right: 0,
                                                            bottom: 0,
                                                            child: Container(
                                                              height: 30,
                                                              width: 60,
                                                              decoration: const BoxDecoration(
                                                                color: ThemeProvider.appColor,
                                                                borderRadius: BorderRadius.only(topLeft: Radius.circular(10), bottomRight: Radius.circular(10)),
                                                              ),
                                                              child: Row(
                                                                mainAxisAlignment: MainAxisAlignment.center,
                                                                children: [Text('Book'.tr, style: const TextStyle(fontSize: 10, color: Colors.white))],
                                                              ),
                                                            ),
                                                          ),
                                                        ],
                                                      ),
                                                    ),
                                                  ],
                                                ),
                                              ),
                                            ),
                                        ],
                                      ),
                                    ),
                                  ),
                                ),
                              ],
                            ),
                          )
                        ],
                      ),
                    )
                  : Column(
                      crossAxisAlignment: CrossAxisAlignment.center,
                      mainAxisAlignment: MainAxisAlignment.center,
                      children: [
                        const SizedBox(height: 20),
                        SizedBox(height: 80, width: 80, child: Image.asset("assets/images/no-data.png", fit: BoxFit.cover)),
                        const SizedBox(height: 30),
                        Center(child: Text('No Data Found Near You!'.tr, style: const TextStyle(fontFamily: 'bold'))),
                      ],
                    ),
        );
      },
    );
  }
}
